@@ -47,7 +47,7 @@
 #include "Configuration.h"
 #include "GameArea.h"
 
-static Lum::AppInfo info;
+static Lum::Def::AppInfo info;
 
 typedef Lum::Model::StdTable<Collection*>      CollectionsModel;
 typedef Lum::Base::Reference<CollectionsModel> CollectionsModelRef;
